@@ -1,8 +1,8 @@
 /**************************************
-           VERSIONED VIEWS (3.2)
+           VERSIONED VIEWS (3.1)
 **************************************/
 
-CREATE OR REPLACE VIEW v3_2_enum_translator
+CREATE OR REPLACE VIEW v3_1_enum_translator_view
  AS
 SELECT
     enum_translator.enum_type as enum_type,
@@ -13,7 +13,7 @@ FROM enum_translator INNER JOIN
                 (enum_translator.language_code = history_configuration.var_value
                 and history_configuration.var_name = 'default_language');
 
-CREATE OR REPLACE VIEW v3_2_configuration_history_datacenters
+CREATE OR REPLACE VIEW v3_1_datacenter_configuration_view
  AS
 SELECT
       history_id as history_id,
@@ -29,7 +29,7 @@ SELECT
       delete_date as delete_date
 FROM datacenter_configuration;
 
-CREATE OR REPLACE VIEW v3_2_latest_configuration_datacenters
+CREATE OR REPLACE VIEW v3_1_latest_datacenter_configuration_view
  AS
 SELECT
       history_id as history_id,
@@ -46,7 +46,7 @@ FROM datacenter_configuration
 WHERE history_id in (SELECT max(a.history_id) FROM datacenter_configuration as a GROUP BY a.datacenter_id)
       and delete_date IS NULL;
 
-CREATE OR REPLACE VIEW v3_2_statistics_datacenters_resources_usage_samples
+CREATE OR REPLACE VIEW v3_1_datacenter_samples_history_view
  AS
 SELECT
       history_id as history_id,
@@ -57,7 +57,7 @@ SELECT
       datacenter_configuration_version as datacenter_configuration_version
 FROM datacenter_samples_history;
 
-CREATE OR REPLACE VIEW v3_2_statistics_datacenters_resources_usage_hourly
+CREATE OR REPLACE VIEW v3_1_datacenter_hourly_history_view
  AS
 SELECT
       history_id as history_id,
@@ -68,7 +68,7 @@ SELECT
       datacenter_configuration_version as datacenter_configuration_version
 FROM datacenter_hourly_history;
 
-CREATE OR REPLACE VIEW v3_2_statistics_datacenters_resources_usage_daily
+CREATE OR REPLACE VIEW v3_1_datacenter_daily_history_view
  AS
 SELECT
       history_id as history_id,
@@ -79,7 +79,7 @@ SELECT
       datacenter_configuration_version as datacenter_configuration_version
 FROM datacenter_daily_history;
 
-CREATE OR REPLACE VIEW v3_2_map_history_datacenters_storage_domains
+CREATE OR REPLACE VIEW v3_1_datacenter_storage_domain_map_view
  AS
 SELECT
     history_id as history_id,
@@ -89,7 +89,7 @@ SELECT
     detach_date as detach_date
 FROM         datacenter_storage_domain_map;
 
-CREATE OR REPLACE VIEW v3_2_latest_map_datacenters_storage_domains
+CREATE OR REPLACE VIEW v3_1_latest_datacenter_storage_domain_map_view
  AS
 SELECT
     history_id as history_id,
@@ -100,7 +100,7 @@ FROM         datacenter_storage_domain_map
 WHERE history_id in (SELECT max(a.history_id) FROM datacenter_storage_domain_map as a GROUP BY a.storage_domain_id, a.datacenter_id)
       and detach_date IS NULL;
 
-CREATE OR REPLACE VIEW v3_2_configuration_history_storage_domains
+CREATE OR REPLACE VIEW v3_1_storage_domain_configuration_view
  AS
 SELECT
       history_id as history_id,
@@ -113,7 +113,7 @@ SELECT
       delete_date as delete_date
 FROM storage_domain_configuration;
 
-CREATE OR REPLACE VIEW v3_2_latest_configuration_storage_domains
+CREATE OR REPLACE VIEW v3_1_latest_storage_domain_configuration_view
  AS
 SELECT
       history_id as history_id,
@@ -127,46 +127,43 @@ FROM storage_domain_configuration
 WHERE history_id in (SELECT max(a.history_id) FROM storage_domain_configuration as a GROUP BY a.storage_domain_id)
       and delete_date IS NULL;
 
-CREATE OR REPLACE VIEW v3_2_statistics_storage_domains_resources_usage_samples
+CREATE OR REPLACE VIEW v3_1_storage_domain_samples_history_view
  AS
 SELECT
-      history_id as history_id,
+      min(history_id) as history_id,
       history_datetime as history_datetime,
       storage_domain_id as storage_domain_id,
-      storage_domain_status,
-      minutes_in_status,
-      available_disk_size_gb as available_disk_size_gb,
-      used_disk_size_gb as used_disk_size_gb,
-      storage_configuration_version as storage_configuration_version
-FROM storage_domain_samples_history;
+      max(available_disk_size_gb) as available_disk_size_gb,
+      max(used_disk_size_gb) as used_disk_size_gb,
+      max(storage_configuration_version) as storage_configuration_version
+FROM storage_domain_samples_history
+GROUP BY history_datetime, storage_domain_id;
 
-CREATE OR REPLACE VIEW v3_2_statistics_storage_domains_resources_usage_hourly
+CREATE OR REPLACE VIEW v3_1_storage_domain_hourly_history_view
  AS
 SELECT
-      history_id as history_id,
+      min(history_id) as history_id,
       history_datetime as history_datetime,
       storage_domain_id as storage_domain_id,
-      storage_domain_status,
-      minutes_in_status,
-      available_disk_size_gb as available_disk_size_gb,
-      used_disk_size_gb as used_disk_size_gb,
-      storage_configuration_version as storage_configuration_version
-FROM storage_domain_hourly_history;
+      max(available_disk_size_gb) as available_disk_size_gb,
+      max(used_disk_size_gb) as used_disk_size_gb,
+      max(storage_configuration_version) as storage_configuration_version
+FROM storage_domain_hourly_history
+GROUP BY history_datetime, storage_domain_id;
 
-CREATE OR REPLACE VIEW v3_2_statistics_storage_domains_resources_usage_daily
+CREATE OR REPLACE VIEW v3_1_storage_domain_daily_history_view
  AS
 SELECT
-      history_id as history_id,
+      min(history_id) as history_id,
       history_datetime as history_datetime,
       storage_domain_id as storage_domain_id,
-      storage_domain_status,
-      minutes_in_status,
-      available_disk_size_gb as available_disk_size_gb,
-      used_disk_size_gb as used_disk_size_gb,
-      storage_configuration_version as storage_configuration_version
-FROM storage_domain_daily_history;
+      max(available_disk_size_gb) as available_disk_size_gb,
+      max(used_disk_size_gb) as used_disk_size_gb,
+      max(storage_configuration_version) as storage_configuration_version
+FROM storage_domain_daily_history
+GROUP BY history_datetime, storage_domain_id;
 
-CREATE OR REPLACE VIEW v3_2_configuration_history_clusters
+CREATE OR REPLACE VIEW v3_1_cluster_configuration_view
  AS
 SELECT
       history_id as history_id,
@@ -182,7 +179,7 @@ SELECT
       delete_date as delete_date
 FROM cluster_configuration;
 
-CREATE OR REPLACE VIEW v3_2_latest_configuration_clusters
+CREATE OR REPLACE VIEW v3_1_latest_cluster_configuration_view
  AS
 SELECT
       history_id as history_id,
@@ -199,7 +196,7 @@ FROM cluster_configuration
 WHERE history_id in (SELECT max(a.history_id) FROM cluster_configuration as a GROUP BY a.cluster_id)
       and delete_date IS NULL;
 
-CREATE OR REPLACE VIEW v3_2_configuration_history_hosts
+CREATE OR REPLACE VIEW v3_1_host_configuration_view
  AS
 SELECT
       history_id as history_id,
@@ -232,7 +229,7 @@ SELECT
       delete_date as delete_date
 FROM host_configuration;
 
-CREATE OR REPLACE VIEW v3_2_latest_configuration_hosts
+CREATE OR REPLACE VIEW v3_1_latest_host_configuration_view
  AS
 SELECT
       history_id as history_id,
@@ -266,7 +263,7 @@ FROM host_configuration
 WHERE history_id in (SELECT max(a.history_id) FROM host_configuration as a GROUP BY a.host_id)
       and delete_date IS NULL;
 
-CREATE OR REPLACE VIEW v3_2_statistics_hosts_resources_usage_samples
+CREATE OR REPLACE VIEW v3_1_host_samples_history_view
  AS
 SELECT
       history_id as history_id,
@@ -287,7 +284,7 @@ SELECT
       host_configuration_version as host_configuration_version
 FROM host_samples_history;
 
-CREATE OR REPLACE VIEW v3_2_statistics_hosts_resources_usage_hourly
+CREATE OR REPLACE VIEW v3_1_host_hourly_history_view
  AS
 SELECT
       history_id as history_id,
@@ -318,7 +315,7 @@ SELECT
       host_configuration_version as host_configuration_version
 FROM host_hourly_history;
 
-CREATE OR REPLACE VIEW v3_2_statistics_hosts_resources_usage_daily
+CREATE OR REPLACE VIEW v3_1_host_daily_history_view
  AS
 SELECT
       history_id as history_id,
@@ -349,7 +346,7 @@ SELECT
       host_configuration_version as host_configuration_version
 FROM host_daily_history;
 
-CREATE OR REPLACE VIEW v3_2_configuration_history_hosts_interfaces
+CREATE OR REPLACE VIEW v3_1_host_interface_configuration_view
  AS
 SELECT
       history_id as history_id,
@@ -371,7 +368,7 @@ SELECT
       delete_date as delete_date
 FROM host_interface_configuration;
 
-CREATE OR REPLACE VIEW v3_2_latest_configuration_hosts_interfaces
+CREATE OR REPLACE VIEW v3_1_latest_host_interface_configuration_view
  AS
 SELECT
       history_id as history_id,
@@ -394,7 +391,7 @@ FROM host_interface_configuration
 WHERE history_id in (SELECT max(a.history_id) FROM host_interface_configuration as a GROUP BY a.host_interface_id)
       and delete_date IS NULL;
 
-CREATE OR REPLACE VIEW v3_2_statistics_hosts_interfaces_resources_usage_samples
+CREATE OR REPLACE VIEW v3_1_host_interface_samples_history_view
  AS
 SELECT
       history_id as history_id,
@@ -405,7 +402,7 @@ SELECT
       host_interface_configuration_version as host_interface_configuration_version
 FROM host_interface_samples_history;
 
-CREATE OR REPLACE VIEW v3_2_statistics_hosts_interfaces_resources_usage_hourly
+CREATE OR REPLACE VIEW v3_1_host_interface_hourly_history_view
  AS
 SELECT
       history_id as history_id,
@@ -418,7 +415,7 @@ SELECT
       host_interface_configuration_version as host_interface_configuration_version
 FROM host_interface_hourly_history;
 
-CREATE OR REPLACE VIEW v3_2_statistics_hosts_interfaces_resources_usage_daily
+CREATE OR REPLACE VIEW v3_1_host_interface_daily_history_view
  AS
 
 SELECT
@@ -432,7 +429,7 @@ SELECT
       host_interface_configuration_version as host_interface_configuration_version
 FROM host_interface_daily_history;
 
-CREATE OR REPLACE VIEW v3_2_configuration_history_vms
+CREATE OR REPLACE VIEW v3_1_vm_configuration_view
  AS
 SELECT
       history_id as history_id,
@@ -453,6 +450,7 @@ SELECT
       initialized as initialized,
       stateless as stateless,
       fail_back as fail_back,
+      FALSE as auto_suspend,
       usb_policy as usb_policy,
       time_zone as time_zone,
       cluster_configuration_version as cluster_configuration_version,
@@ -462,7 +460,7 @@ SELECT
       delete_date as delete_date
 FROM vm_configuration;
 
-CREATE OR REPLACE VIEW v3_2_latest_configuration_vms
+CREATE OR REPLACE VIEW v3_1_latest_vm_configuration_view
  AS
 SELECT
       history_id as history_id,
@@ -483,6 +481,7 @@ SELECT
       initialized as initialized,
       stateless as stateless,
       fail_back as fail_back,
+      FALSE as auto_suspend,
       usb_policy as usb_policy,
       time_zone as time_zone,
       cluster_configuration_version as cluster_configuration_version,
@@ -493,7 +492,7 @@ FROM vm_configuration
 WHERE history_id in (SELECT max(a.history_id) FROM vm_configuration as a GROUP BY a.vm_id)
       and delete_date IS NULL;
 
-CREATE OR REPLACE VIEW v3_2_statistics_vms_resources_usage_samples
+CREATE OR REPLACE VIEW v3_1_vm_samples_history_view
  AS
 SELECT
     a.history_id as history_id,
@@ -505,7 +504,7 @@ SELECT
     a.memory_usage_percent as memory_usage_percent,
     a.user_cpu_usage_percent as user_cpu_usage_percent,
     a.system_cpu_usage_percent as system_cpu_usage_percent,
-    a.vm_ip as vm_ip,
+    cast(a.vm_ip as varchar(255)) as vm_ip,
     a.currently_running_on_host as currently_running_on_host,
     COALESCE(users.username, a.current_user_name) as current_user_name,
     b.disks_usage as disks_usage,
@@ -517,7 +516,7 @@ FROM vm_samples_history as a
     LEFT OUTER JOIN users_details_history as users
         ON (a.current_user_id = users.user_id);
 
-CREATE OR REPLACE VIEW v3_2_statistics_vms_resources_usage_hourly
+CREATE OR REPLACE VIEW v3_1_vm_hourly_history_view
  AS
 SELECT
     a.history_id as history_id,
@@ -533,7 +532,7 @@ SELECT
     a.max_user_cpu_usage_percent as max_user_cpu_usage_percent,
     a.system_cpu_usage_percent as system_cpu_usage_percent,
     a.max_system_cpu_usage_percent as max_system_cpu_usage_percent,
-    a.vm_ip as vm_ip,
+    cast(a.vm_ip as varchar(255)) as vm_ip,
     a.currently_running_on_host as currently_running_on_host,
     COALESCE(users.username, a.current_user_name) as current_user_name,
     b.disks_usage as disks_usage,
@@ -543,9 +542,9 @@ FROM vm_hourly_history as a
     LEFT OUTER JOIN vm_disks_usage_hourly_history as b
         ON (a.history_datetime = b.history_datetime AND a.vm_id = b.vm_id)
     LEFT OUTER JOIN users_details_history as users
-      ON (a.current_user_id = users.user_id);
+        ON (a.current_user_id = users.user_id);
 
-CREATE OR REPLACE VIEW v3_2_statistics_vms_resources_usage_daily
+CREATE OR REPLACE VIEW v3_1_vm_daily_history_view
  AS
 SELECT
     a.history_id as history_id,
@@ -561,65 +560,19 @@ SELECT
     a.max_user_cpu_usage_percent as max_user_cpu_usage_percent,
     a.system_cpu_usage_percent as system_cpu_usage_percent,
     a.max_system_cpu_usage_percent as max_system_cpu_usage_percent,
-    a.vm_ip as vm_ip,
+    cast(a.vm_ip as varchar(255)) as vm_ip,
     a.currently_running_on_host as currently_running_on_host,
-    a.current_user_name as current_user_name,
+    COALESCE(users.username, a.current_user_name) as current_user_name,
     b.disks_usage as disks_usage,
     a.vm_configuration_version as vm_configuration_version,
     a.current_host_configuration_version as current_host_configuration_version
 FROM vm_daily_history as a
     LEFT OUTER JOIN vm_disks_usage_daily_history as b
-        ON (a.history_datetime = b.history_datetime AND a.vm_id = b.vm_id);
-
-CREATE OR REPLACE VIEW v3_2_statistics_vms_users_usage_hourly
- AS
-SELECT
-    a.history_id,
-    a.history_datetime,
-    COALESCE(users.username, a.user_name) as user_name,
-    a.vm_id,
-    a.session_time_in_minutes,
-    a.cpu_usage_percent,
-    a.max_cpu_usage,
-    a.memory_usage_percent,
-    a.max_memory_usage,
-    a.user_cpu_usage_percent,
-    a.max_user_cpu_usage_percent,
-    a.system_cpu_usage_percent,
-    a.max_system_cpu_usage_percent,
-    a.vm_ip,
-    a.currently_running_on_host,
-    a.vm_configuration_version,
-    a.current_host_configuration_version
-FROM statistics_vms_users_usage_hourly as a
+        ON (a.history_datetime = b.history_datetime AND a.vm_id = b.vm_id)
     LEFT OUTER JOIN users_details_history as users
-        ON (a.user_id = users.user_id);
+        ON (a.current_user_id = users.user_id);
 
-CREATE OR REPLACE VIEW v3_2_statistics_vms_users_usage_daily
- AS
-SELECT
-    a.history_id,
-    a.history_datetime,
-    COALESCE(users.username, a.user_name) as user_name,
-    a.vm_id,
-    a.session_time_in_minutes,
-    a.cpu_usage_percent,
-    a.max_cpu_usage,
-    a.memory_usage_percent,
-    a.max_memory_usage,
-    a.user_cpu_usage_percent,
-    a.max_user_cpu_usage_percent,
-    a.system_cpu_usage_percent,
-    a.max_system_cpu_usage_percent,
-    a.vm_ip,
-    a.currently_running_on_host,
-    a.vm_configuration_version,
-    a.current_host_configuration_version
-FROM statistics_vms_users_usage_daily as a
-    LEFT OUTER JOIN users_details_history as users
-        ON (a.user_id = users.user_id);
-
-CREATE OR REPLACE VIEW v3_2_configuration_history_vms_interfaces
+CREATE OR REPLACE VIEW v3_1_vm_interface_configuration_view
  AS
 SELECT
       history_id as history_id,
@@ -635,7 +588,7 @@ SELECT
       delete_date as delete_date
 FROM vm_interface_configuration;
 
-CREATE OR REPLACE VIEW v3_2_latest_configuration_vms_interfaces
+CREATE OR REPLACE VIEW v3_1_latest_vm_interface_configuration_view
  AS
 SELECT
       history_id as history_id,
@@ -652,7 +605,7 @@ FROM vm_interface_configuration
 WHERE history_id in (SELECT max(a.history_id) FROM vm_interface_configuration as a GROUP BY a.vm_interface_id)
       and delete_date IS NULL;
 
-CREATE OR REPLACE VIEW v3_2_statistics_vms_interfaces_resources_usage_samples
+CREATE OR REPLACE VIEW v3_1_vm_interface_samples_history_view
  AS
 
 SELECT
@@ -664,7 +617,7 @@ SELECT
       vm_interface_configuration_version as vm_interface_configuration_version
 FROM vm_interface_samples_history;
 
-CREATE OR REPLACE VIEW v3_2_statistics_vms_interfaces_resources_usage_hourly
+CREATE OR REPLACE VIEW v3_1_vm_interface_hourly_history_view
  AS
 
 SELECT
@@ -678,7 +631,7 @@ SELECT
       vm_interface_configuration_version as vm_interface_configuration_version
 FROM vm_interface_hourly_history;
 
-CREATE OR REPLACE VIEW v3_2_statistics_vms_interfaces_resources_usage_daily
+CREATE OR REPLACE VIEW v3_1_vm_interface_daily_history_view
  AS
 
 SELECT
@@ -692,7 +645,7 @@ SELECT
       vm_interface_configuration_version as vm_interface_configuration_version
 FROM vm_interface_daily_history;
 
-CREATE OR REPLACE VIEW v3_2_configuration_history_vms_disks
+CREATE OR REPLACE VIEW v3_1_vm_disk_configuration_view
  AS
 SELECT
     history_id as history_id,
@@ -714,7 +667,7 @@ SELECT
     delete_date as delete_date
 FROM vm_disk_configuration;
 
-CREATE OR REPLACE VIEW v3_2_latest_configuration_vms_disks
+CREATE OR REPLACE VIEW v3_1_latest_vm_disk_configuration_view
  AS
 SELECT
     history_id as history_id,
@@ -737,7 +690,7 @@ FROM vm_disk_configuration
 WHERE history_id in (SELECT max(a.history_id) FROM vm_disk_configuration as a GROUP BY a.vm_disk_id)
       and delete_date IS NULL;
 
-CREATE OR REPLACE VIEW v3_2_statistics_vms_disks_resources_usage_samples
+CREATE OR REPLACE VIEW v3_1_vm_disk_samples_history_view
  AS
 SELECT
     history_id as history_id,
@@ -754,7 +707,7 @@ SELECT
     vm_disk_configuration_version as vm_disk_configuration_version
 FROM vm_disk_samples_history;
 
-CREATE OR REPLACE VIEW v3_2_statistics_vms_disks_resources_usage_hourly
+CREATE OR REPLACE VIEW v3_1_vm_disk_hourly_history_view
  AS
 SELECT
     history_id as history_id,
@@ -776,7 +729,7 @@ SELECT
     vm_disk_configuration_version as vm_disk_configuration_version
 FROM vm_disk_hourly_history;
 
-CREATE OR REPLACE VIEW v3_2_statistics_vms_disks_resources_usage_daily
+CREATE OR REPLACE VIEW v3_1_vm_disk_daily_history_view
  AS
 SELECT
     history_id as history_id,
@@ -798,7 +751,7 @@ SELECT
     vm_disk_configuration_version as vm_disk_configuration_version
 FROM vm_disk_daily_history;
 
-CREATE OR REPLACE VIEW v3_2_configuration_history_vms_devices
+CREATE OR REPLACE VIEW v3_1_vm_device_history_view
  AS
 SELECT
     history_id as history_id,
@@ -816,7 +769,7 @@ SELECT
     delete_date
 FROM vm_device_history;
 
-CREATE OR REPLACE VIEW v3_2_latest_configuration_vms_devices
+CREATE OR REPLACE VIEW v3_1_latest_vm_device_history_view
  AS
 SELECT
     history_id as history_id,
@@ -835,7 +788,7 @@ FROM vm_device_history
 WHERE history_id in (SELECT max(a.history_id) FROM vm_device_history as a GROUP BY a.vm_id, a.device_id)
       and delete_date IS NULL;
 
-CREATE OR REPLACE VIEW v3_2_tags_relations_history
+CREATE OR REPLACE VIEW v3_1_tag_relations_history_view
  AS
 SELECT    history_id as history_id,
         entity_id as entity_id,
@@ -846,7 +799,7 @@ SELECT    history_id as history_id,
 FROM         tag_relations_history
 WHERE       entity_type in(3,2,5,18);
 
-CREATE OR REPLACE VIEW v3_2_latest_tags_relations
+CREATE OR REPLACE VIEW v3_1_latest_tag_relations_history_view
  AS
 SELECT    history_id as history_id,
         entity_id as entity_id,
@@ -859,7 +812,7 @@ WHERE       entity_type in(3,2,5,18)
        and history_id in (SELECT max(a.history_id) FROM tag_relations_history as a GROUP BY a.entity_id, a.parent_id)
        and detach_date IS NULL;
 
-CREATE OR REPLACE VIEW v3_2_tags_details_history
+CREATE OR REPLACE VIEW v3_1_tag_details_view
  AS
 SELECT  history_id as history_id,
         tag_id as tag_id,
@@ -872,7 +825,7 @@ SELECT  history_id as history_id,
         delete_date as delete_date
 FROM         tag_details;
 
-CREATE OR REPLACE VIEW v3_2_latest_tags_details
+CREATE OR REPLACE VIEW v3_1_latest_tag_details_view
  AS
 SELECT  history_id as history_id,
         tag_id as tag_id,
